<?php
/*
Plugin Name: Simple Google Map
Description: A simple plugin to display a Google Map at a specified location with default settings.
Version: 1.1
Author: EasyToolsWP.com
*/

// Function to output the Google Map
function display_google_map($atts) {
    // Retrieve default settings from the database
    $default_address = get_option('google_map_address', 'øksen 3, 2630 Taastrup');
    $default_zoom = get_option('google_map_zoom', '8');

    // Parse shortcode attributes
    $atts = shortcode_atts(
        array(
            'destination' => $default_address,
            'zoom' => $default_zoom,
        ),
        $atts,
        'google_map'
    );

    $destination = urlencode($atts['destination']);
    $zoom = intval($atts['zoom']);
    $map_url = "https://www.google.com/maps/embed/v1/place?q={$destination}&zoom={$zoom}";

    return "<iframe
                width='600'
                height='450'
                frameborder='0'
                style='border:0'
                src='{$map_url}'
                allowfullscreen>
            </iframe>";
}

// Register the shortcode
add_shortcode('google_map', 'display_google_map');

// Add settings menu
function google_map_menu() {
    add_options_page(
        'Google Map Settings',
        'Google Map',
        'manage_options',
        'google-map-settings',
        'google_map_settings_page'
    );
}
add_action('admin_menu', 'google_map_menu');

// Settings page
function google_map_settings_page() {
    ?>
    <div class="wrap">
        <h1>Google Map Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('google_map_options_group');
            do_settings_sections('google_map_settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register settings
function google_map_settings_init() {
    register_setting('google_map_options_group', 'google_map_address');
    register_setting('google_map_options_group', 'google_map_zoom');

    add_settings_section(
        'google_map_settings_section',
        'Default Settings',
        null,
        'google_map_settings'
    );

    add_settings_field(
        'google_map_address',
        'Address',
        'google_map_address_callback',
        'google_map_settings',
        'google_map_settings_section'
    );

    add_settings_field(
        'google_map_zoom',
        'Zoom Level',
        'google_map_zoom_callback',
        'google_map_settings',
        'google_map_settings_section'
    );
}
add_action('admin_init', 'google_map_settings_init');

// Callback functions for settings fields
function google_map_address_callback() {
    $address = get_option('google_map_address', 'øksen 3, 2630 Taastrup');
    echo "<input type='text' name='google_map_address' value='" . esc_attr($address) . "' />";
}

function google_map_zoom_callback() {
    $zoom = get_option('google_map_zoom', '8');
    echo "<input type='number' name='google_map_zoom' value='" . esc_attr($zoom) . "' min='0' max='21' />";
}
